==> perseus-size-opt-0.1.7.crate: perseus-size-opt-0.1.7/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### [0.1.7](https://github.com/arctic-hen7/perseus-size-opt/compare/v0.1.6...v0.1.7) (2021-12-21)

### [0.1.6](https://github.com/arctic-hen7/perseus-size-opt/compare/v0.1.5...v0.1.6) (2021-12-20)

### [0.1.5](https://github.com/arctic-hen7/perseus-size-opt/compare/v0.1.4...v0.1.5) (2021-12-13)


### Features

* updated to support latest perseus/sycamore ([081544a](https://github.com/arctic-hen7/perseus-size-opt/commit/081544a7a9d7ab4040415847036a9dd3bf3a29e0))

### [0.1.4](https://github.com/arctic-hen7/perseus-size-opt/compare/v0.1.3...v0.1.4) (2021-12-02)


### Bug Fixes

* added patch for `fluent-bundle` ([130222b](https://github.com/arctic-hen7/perseus-size-opt/commit/130222b7596082a79d0973f17b3990e66ddfd4b6))

### [0.1.3](https://github.com/arctic-hen7/perseus-size-opt/compare/v0.1.2...v0.1.3) (2021-11-29)

### [0.1.2](https://github.com/arctic-hen7/perseus-size-opt/compare/v0.1.1...v0.1.2) (2021-11-07)

### [0.1.1](https://github.com/arctic-hen7/perseus-size-opt/compare/v0.1.0...v0.1.1) (2021-10-30)


### Documentation Changes

* 📝 added readme warning about Perseus [#66](https://github.com/arctic-hen7/perseus-size-opt/issues/66) ([8fafa43](https://github.com/arctic-hen7/perseus-size-opt/commit/8fafa43f6931e161f606e01bfcf1be5f703e3fc8))


### Code Refactorings

* ✏️ changed title of example from `Tiny` to `Simple` ([#2](https://github.com/arctic-hen7/perseus-size-opt/issues/2)) ([a6b192b](https://github.com/arctic-hen7/perseus-size-opt/commit/a6b192b0a170908049516186f319e611a03948e6))
* 👽️ updated for latest perseus version ([989d235](https://github.com/arctic-hen7/perseus-size-opt/commit/989d235b21eea45bc8a0273f3a9a248933db7330)), closes [#1](https://github.com/arctic-hen7/perseus-size-opt/issues/1)

## 0.1.0 (2021-10-19)


### Features

* ✨ added plugin functionality and docs ([37c6a07](https://github.com/arctic-hen7/perseus-size-opt/commit/37c6a07242c3787641d36d09bb749d0b8ab5d9f8))
* 🎉 added basic oss boilerplate ([f3c8fa5](https://github.com/arctic-hen7/perseus-size-opt/commit/f3c8fa54255bcaa6b5a55024f45c668623bc116b))


### Bug Fixes

* 📝 fixed link in readme ([afe4481](https://github.com/arctic-hen7/perseus-size-opt/commit/afe448143e9fd6765e3a900fa69a18c45dec733f))

==> perseus-size-opt-0.1.8.crate: perseus-size-opt-0.1.8/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### [0.1.8](https://github.com/arctic-hen7/perseus-size-opt/compare/v0.1.7...v0.1.8) (2022-04-20)


### Features

* upgraded for perseus v0.3.4 ([bcfbc68](https://github.com/arctic-hen7/perseus-size-opt/commit/bcfbc68ace29b7fd15f1ed7ef70dc7930cb65b45))

### [0.1.7](https://github.com/arctic-hen7/perseus-size-opt/compare/v0.1.6...v0.1.7) (2021-12-21)

### [0.1.6](https://github.com/arctic-hen7/perseus-size-opt/compare/v0.1.5...v0.1.6) (2021-12-20)

### [0.1.5](https://github.com/arctic-hen7/perseus-size-opt/compare/v0.1.4...v0.1.5) (2021-12-13)


### Features

* updated to support latest perseus/sycamore ([081544a](https://github.com/arctic-hen7/perseus-size-opt/commit/081544a7a9d7ab4040415847036a9dd3bf3a29e0))

### [0.1.4](https://github.com/arctic-hen7/perseus-size-opt/compare/v0.1.3...v0.1.4) (2021-12-02)


### Bug Fixes

* added patch for `fluent-bundle` ([130222b](https://github.com/arctic-hen7/perseus-size-opt/commit/130222b7596082a79d0973f17b3990e66ddfd4b6))

### [0.1.3](https://github.com/arctic-hen7/perseus-size-opt/compare/v0.1.2...v0.1.3) (2021-11-29)

### [0.1.2](https://github.com/arctic-hen7/perseus-size-opt/compare/v0.1.1...v0.1.2) (2021-11-07)

### [0.1.1](https://github.com/arctic-hen7/perseus-size-opt/compare/v0.1.0...v0.1.1) (2021-10-30)


### Documentation Changes

* 📝 added readme warning about Perseus [#66](https://github.com/arctic-hen7/perseus-size-opt/issues/66) ([8fafa43](https://github.com/arctic-hen7/perseus-size-opt/commit/8fafa43f6931e161f606e01bfcf1be5f703e3fc8))


### Code Refactorings

* ✏️ changed title of example from `Tiny` to `Simple` ([#2](https://github.com/arctic-hen7/perseus-size-opt/issues/2)) ([a6b192b](https://github.com/arctic-hen7/perseus-size-opt/commit/a6b192b0a170908049516186f319e611a03948e6))
* 👽️ updated for latest perseus version ([989d235](https://github.com/arctic-hen7/perseus-size-opt/commit/989d235b21eea45bc8a0273f3a9a248933db7330)), closes [#1](https://github.com/arctic-hen7/perseus-size-opt/issues/1)

## 0.1.0 (2021-10-19)


### Features

* ✨ added plugin functionality and docs ([37c6a07](https://github.com/arctic-hen7/perseus-size-opt/commit/37c6a07242c3787641d36d09bb749d0b8ab5d9f8))
* 🎉 added basic oss boilerplate ([f3c8fa5](https://github.com/arctic-hen7/perseus-size-opt/commit/f3c8fa54255bcaa6b5a55024f45c668623bc116b))


### Bug Fixes

* 📝 fixed link in readme ([afe4481](https://github.com/arctic-hen7/perseus-size-opt/commit/afe448143e9fd6765e3a900fa69a18c45dec733f))
